@@ -8,7 +8,7 @@ module IssuableActions
     before_action :authorize_destroy_issuable!, only: :destroy
     before_action :authorize_admin_issuable!, only: :bulk_update
     before_action only: :show do
-      push_frontend_feature_flag(:reply_to_individual_notes, default_enabled: true)
+      push_frontend_feature_flag(:scoped_labels, default_enabled: true)
     end
   end
 
