@@ -2,7 +2,7 @@
 
 module Clusters
   module Applications
-    class Jupyter < ActiveRecord::Base
+    class Jupyter < ApplicationRecord
       VERSION = '0.9-174bbd5'.freeze
 
       self.table_name = 'clusters_applications_jupyter'
