@@ -1,6 +1,6 @@
 # frozen_string_literal: true
 
-class ProjectGroupLink < ActiveRecord::Base
+class ProjectGroupLink < ApplicationRecord
   include Expirable
 
   GUEST     = 10
